summaryrefslogtreecommitdiff
path: root/util/new_keyboard.sh
diff options
context:
space:
mode:
Diffstat (limited to 'util/new_keyboard.sh')
-rwxr-xr-xutil/new_keyboard.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/util/new_keyboard.sh b/util/new_keyboard.sh
index 87b7cde0c9..62e8cb9e13 100755
--- a/util/new_keyboard.sh
+++ b/util/new_keyboard.sh
@@ -1,7 +1,7 @@
#!/usr/bin/env bash
# This script generates a new keyboard directory under keyboards/,
# and copies the template files from quantum/template/ into it.
# Print an error message with the word "ERROR" in red.
echo_error() {
@@ -35,11 +35,11 @@ copy_templates() {
mkdir -p "$keyboard_dir"
echo -n "Copying base template files..."
- cp -r "quantum/template/base/." "${keyboard_dir}"
+ cp -r "data/templates/base/." "${keyboard_dir}"
echo " done"
echo -n "Copying $keyboard_type template files..."
- cp -r "quantum/template/${keyboard_type}/." "${keyboard_dir}"
+ cp -r "data/templates/${keyboard_type}/." "${keyboard_dir}"
echo " done"
echo -n "Renaming keyboard files..."
@@ -1,7 +1,7 @@
#!/usr/bin/env bash
# This script generates a new keyboard directory under keyboards/,
-# and copies the template files from quantum/template/ into it.
+# and copies the template files from data/templates/ into it.
# Print an error message with the word "ERROR" in red.
echo_error() {